// rollup.config.js
import { createRequire } from "module";
const require = createRequire(import.meta.url);
import copy from 'rollup-plugin-copy';

import svelte from 'rollup-plugin-svelte';
import commonjs from '@rollup/plugin-commonjs';
import resolve from '@rollup/plugin-node-resolve';
import sveltePreprocess from 'svelte-preprocess';
import typescript from '@rollup/plugin-typescript';
import json from '@rollup/plugin-json';

import postcss from 'rollup-plugin-postcss';

// dependencies
const fs = require("fs")
const postcssglobal = require("postcss")
const atImport = require("postcss-import")

// css to be processed
const globalStyles = fs.readFileSync("src/styles/global.css", "utf8")

// Read the content of the existing CSS file

export default {
  input: 'src/index.ts',
  output: {
    file: 'dist/index.mjs',
    format: 'esm', // or 'esm' depending on your needs
    exports: 'auto',
    sourcemap: true, // Enable source maps
  },
  plugins: [
    svelte({     
      // Enable preprocessing options if needed (e.g., preprocessing Svelte components with Svelte preprocessors)
      preprocess: sveltePreprocess(),
      // Optionally, specify compiler options for Svelte
      compilerOptions: {
        // Custom compiler options, if any
      },
    }),
    resolve({ dedupe: ["svelte"]}),
    commonjs(),
    typescript(),
    json(),
    postcss({
      minimize: true,
      // Extract CSS into a separate file
      extract: false,
    }),
    postcssglobal()
      .use(atImport())
      .process(globalStyles, {
        // `from` option is needed here
        from: "src/styles/global.css"
      })
      .then((result) => {
        const output = result.css
        fs.writeFileSync("dist/spectrum-ui-components.css", result.css)
      }),
    /*copy({
      targets: [
        { src: 'src/*', dest: 'dist', flatten: true }, 
          // Add more copy targets as needed
      ],
    }),*/
    ],
  };
